function [S_dx] = cross_spectral_densities(V,omega,dx)

L_exp = 1.75;   % width of tunnel which the given properties are based on

% turbulence properties
I_u = 0.12;     % horizontal turbulence intensity
I_w = 0.10;     % vertical turbulence intensity
xf_Lu = 1.2;    % turbulence length scale (eddy size) in along-wind direction
xf_Lw = 0.2;    % turbulence length scale (eddy size) in vertical direction
C_u = 5.5;      % co-spectrum parameter
C_w = 2.4;      % co-spectrum parameter
A_u = 19;       % approximated kaimal spectrum parameter
A_w = 3;        % approximated kaimal spectrum parameter

% auto-spectra
f = omega/(2*pi);
f_u_red = f*xf_Lu/V;
S_u_red = A_u*f_u_red./(1+1.5*A_u*f_u_red).^(5/3);
S_u = S_u_red*(I_u*V)^2/f;
f_w_red = f*xf_Lw/V;
S_w_red = A_w*f_w_red./(1+1.5*A_w*f_w_red).^(5/3);
S_w = S_w_red*(I_w*V)^2/f;

% co-spectra
kappa_u = sqrt((2*pi*f/V).^2+(1/xf_Lu).^2);
kappa_w = sqrt((2*pi*f/V).^2+(1/xf_Lw).^2);
Co_uu = max(0,(1-0.5*kappa_u*dx*L_exp*C_u/(2*pi)).*exp(-kappa_u*dx*L_exp*C_u/(2*pi)));
Co_ww = max(0,(1-0.5*kappa_w*dx*L_exp*C_w/(2*pi)).*exp(-kappa_w*dx*L_exp*C_w/(2*pi)));

% cross-spectra (assuming cross spectra between different turbulence
% components are negligible)
S_dx = zeros(2,2);
S_dx(1,1) = S_u*Co_uu;
S_dx(2,2) = S_w*Co_ww;